@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,9 +35,16 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-07-23 - v1.003
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.011.
+
+=item *
+
 2012-06-25 - v1.002
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.007.
+
 =item *
 
 2012-05-28 - v1.001
@@ -242,6 +249,7 @@ ADIZERE
 ADODGE
 ADONG
 ADOPTME
+ADOROSH
 ADRABI
 ADRIAN
 ADRIANA
@@ -338,6 +346,7 @@ AJOHNSON
 AJOLMA
 AJPEACOCK
 AJUNG
+AJWANS
 AJWOOD
 AKALINUX
 AKAPLAN
@@ -812,6 +821,7 @@ BADO
 BAERGAJ
 BAF
 BAGARRE
+BAGET
 BAGGEND
 BAGUINGUA
 BAHOOTYPR
@@ -919,6 +929,7 @@ BDGREGG
 BDLILLEY
 BDONLAN
 BDOWLING
+BDR
 BDRACO
 BDUGGAN
 BDULFER
@@ -1024,6 +1035,7 @@ BHUNTER
 BHUVAN
 BIAFRA
 BIBLIBRE
+BIESZCZAD
 BIGBUG
 BIGGLES
 BIGHIL
@@ -1040,6 +1052,7 @@ BILL
 BILLAUER
 BILLC
 BILLH
+BILLHAILS
 BILLKAMP
 BILLN
 BILLW
@@ -1299,6 +1312,7 @@ BRUNOV
 BRX
 BRYAN
 BRYCE
+BRYONICS
 BRYURECKA
 BSAGO
 BSB
@@ -1556,6 +1570,7 @@ CHATEAU
 CHCHCH
 CHE
 CHEAKO
+CHELLAPPA
 CHEN
 CHENGANG
 CHENRYN
@@ -1602,6 +1617,7 @@ CHRISA
 CHRISARN
 CHRISC
 CHRISCHU
+CHRISFR
 CHRISJ
 CHRISJCRA
 CHRISN
@@ -1739,6 +1755,7 @@ COGENT
 COHTAN
 COKE
 COLEMAN
+COLEMINOR
 COLINCCI
 COLINFINE
 COLINK
@@ -1799,6 +1816,7 @@ COWDAWG
 COWENS
 COWFISH
 CPANEL
+CPANIC
 CPANPERL
 CPATIL
 CPB
@@ -1866,6 +1884,7 @@ CTCSHAW
 CTDEAN
 CTHEUN
 CTHOM
+CTHOR
 CTI
 CTILMES
 CTIMMER
@@ -1909,6 +1928,7 @@ CYCLES
 CYGA
 CYING
 CYK
+CYLFHX
 CYMPAK
 CYPLP
 CZBSD
@@ -2153,6 +2173,7 @@ DELTA
 DEMERY
 DEMIAN
 DEMIURG
+DEMMY
 DENA
 DENIS
 DENKINGER
@@ -2691,6 +2712,7 @@ EHASTINGS
 EHEFFERN
 EHERSHEY
 EHOOD
+EHSAN
 EHSANE
 EIDOLA
 EIDOLON
@@ -2911,6 +2933,7 @@ FAXMODEM
 FAYLAND
 FAYS
 FBONDURRI
+FBORSHEV
 FBRIERE
 FCECCONI
 FCH
@@ -3393,6 +3416,7 @@ GSA
 GSAINIO
 GSAR
 GSAVIX
+GSB
 GSCHLOSS
 GSEAMAN
 GSGANG
@@ -4210,6 +4234,7 @@ JESSSSST
 JESTER
 JESTOCK
 JESUS
+JET
 JETEVE
 JETTERO
 JETTRA
@@ -4783,6 +4808,7 @@ KANISHKA
 KANNA
 KANTE
 KAORU
+KAOSAGNT
 KAPPA
 KARASIK
 KARAVELOV
@@ -4845,6 +4871,7 @@ KDOULEPOV
 KDOWNEY
 KDRANJAN
 KEEDI
+KEEKUNG
 KEICHNER
 KEISUKE
 KEJOKI
@@ -4927,6 +4954,7 @@ KHURT
 KHUSSEIN
 KHW
 KIANWIN
+KID
 KILINRAX
 KILNA
 KILORK
@@ -5036,6 +5064,7 @@ KOLIBRIE
 KOLPAK
 KOLYA
 KOM
+KOMAROV
 KOMORIYA
 KONBUIZM
 KONDO
@@ -5131,6 +5160,7 @@ KUBOTA
 KUDARASP
 KUDINOV
 KUDRA
+KUERBIS
 KULCHENKO
 KULDEEP
 KULP
@@ -5294,6 +5324,7 @@ LENNERTO
 LENNY
 LENZO
 LEO
+LEOBALTER
 LEOCHARRE
 LEOHUA
 LEON
@@ -5347,6 +5378,7 @@ LINCHUS
 LINCOLNB
 LINDNER
 LINK
+LINKDD
 LINKE
 LINMAR
 LINNIN
@@ -5391,6 +5423,7 @@ LOGCHECK
 LOGICUS
 LOGIE
 LOGVINON
+LOIC
 LOICDREUX
 LOKKJU
 LOLO
@@ -6156,6 +6189,7 @@ MMLEVITT
 MMML
 MMORENO
 MMORGAN
+MMORRIS
 MMOYLE
 MMUELLER
 MMULLI
@@ -6371,6 +6405,7 @@ MTROWBRI
 MTRUE
 MTURK
 MUCKER
+MUDDYDIXN
 MUELLERW
 MUELLI
 MUENALAN
@@ -6426,6 +6461,7 @@ MXF
 MYAKININ
 MYB
 MYBOXEN
+MYDMNSN
 MYFINDER
 MYKL
 MYNEID
@@ -6528,6 +6564,7 @@ NEKOKAK
 NEKOYA
 NELHAGE
 NELIO
+NELO
 NELSONC
 NEMUX
 NEMWS
@@ -6637,6 +6674,7 @@ NLNETLABS
 NMAKAROV
 NMARCI
 NMARDEN
+NMARLEY
 NMCFARL
 NMELNICK
 NMMSEP
@@ -6721,6 +6759,7 @@ NWIGER
 NWILLIAMS
 NWINT
 NWRIGHT
+NWTOUR
 NXADM
 NXONEP
 NYAKNYAN
@@ -6756,6 +6795,7 @@ OGB
 OGMONSTER
 OHA
 OHOLLMEN
+OHOUSHYAR
 OHREALLY
 OHRT
 OHWOW
@@ -6986,6 +7026,7 @@ PEPE
 PEPL
 PEREINAR
 PEREZ
+PERFORB
 PERFORIN
 PERFSONAR
 PERHENRIK
@@ -7320,6 +7361,7 @@ PUNYTAN
 PURDY
 PURL
 PURP
+PUSHPARAJ
 PVANDE
 PVANDRY
 PVERD
@@ -7401,6 +7443,7 @@ RAMESH
 RAMESHG
 RAMGOPAL
 RAMKI
+RAMPAGEAI
 RAMSDEND
 RAMTEK
 RANA
@@ -7502,6 +7545,7 @@ RDUARTE
 REALHOLGI
 REATMON
 REBEL
+REBX
 RECKON
 RECLAW
 RECORDOND
@@ -7530,6 +7574,7 @@ REIVEUNE
 RELAIS
 RELIANCE
 REMI
+RENAN
 RENEEB
 RENELSON
 RENNERT
@@ -7769,6 +7814,7 @@ ROOTKWOK
 ROOTLEVEL
 ROOTROUTE
 RORY
+ROS
 ROSCH
 ROSCIO
 ROSSEY
@@ -7845,6 +7891,7 @@ RUDY
 RUEYCHENG
 RUFF
 RUITTENB
+RULIX
 RUMCHO
 RUNE
 RUR
@@ -8091,6 +8138,7 @@ SEANM
 SEANO
 SEANQ
 SEB
+SEBA
 SEBASTIAN
 SEBDIAZ
 SEBNOW
@@ -8263,6 +8311,7 @@ SHYOKOU
 SIC
 SID
 SIDD
+SIDIBE
 SIEMERSN
 SIERRA
 SIFUKURT
@@ -8271,8 +8320,10 @@ SIGIZ
 SIGJE
 SIGURKO
 SIGZERO
+SILAS
 SILASMONK
 SILI
+SILLYMOOS
 SILVAN
 SILVER
 SILVIOQ
@@ -8291,6 +8342,7 @@ SIMONF
 SIMONFLK
 SIMONG
 SIMONHF
+SIMONIKI
 SIMONJ
 SIMONMCC
 SIMONP
@@ -8412,6 +8464,7 @@ SMPETERS
 SMPILL
 SMRBRTS
 SMRZ
+SMS
 SMTHAMES
 SMUELLER
 SMULLIS
@@ -8581,6 +8634,7 @@ SSOURABH
 SSWAM
 STABILE
 STAJICH
+STAKASHIO
 STANM
 STANS
 STARKY
@@ -8724,6 +8778,7 @@ SVENTECH
 SVERBERN
 SVIEBROCK
 SVINTO
+SVISTUNOV
 SVITENTI
 SVOELKEL
 SVV
@@ -8914,6 +8969,7 @@ TFHEEN
 TFJELL
 TFM
 TFOUCART
+TFPBL
 TFRAYNER
 TGAETZ
 TGC
@@ -8951,6 +9007,7 @@ THOM
 THOMAS
 THOMSON
 THOR
+THORGIS
 THORIE
 THORIKAWA
 THORSTT
@@ -8964,6 +9021,7 @@ THUNDERA
 THUNDERS
 THW
 TIAGOSOUS
+TIAO
 TIBBS
 TIBI
 TIGERPERL
@@ -9771,6 +9829,7 @@ YLU
 YNONP
 YNOTMGMA
 YOBERT
+YOCC
 YODA
 YOGESHATE
 YOHAMED
@@ -9842,6 +9901,7 @@ ZANDET
 ZANGHIHU
 ZAPHAR
 ZAPHER
+ZARABOZO
 ZARDOZ
 ZARQUON
 ZAXO
@@ -9878,6 +9938,7 @@ ZETA
 ZEV
 ZEYA
 ZGH
+ZGRIM
 ZHANGBO
 ZHANGHJ
 ZHANGL
@@ -9900,6 +9961,7 @@ ZIMMERR
 ZINCDEV
 ZIPPO
 ZIPPY
+ZITOLOCO
 ZIYA
 ZJFDLUT
 ZJT
